phovea_server 
=====================
[![Phovea][phovea-image]][phovea-url] [![Build Status][circleci-image]][circleci-url]


Python server implementation of Phovea that provides: 

* Data set handling
* Reading data from CSV
* ID mapping
* Selection and range handling
* General graph implementation
* WebSocket stream

Installation
------------

```
git clone https://github.com/phovea/phovea_server.git
cd phovea_server
npm install
```

Testing
-------

```
npm test
```

Building
--------

```
npm run build
```



***

<a href="https://caleydo.org"><img src="http://caleydo.org/assets/images/logos/caleydo.svg" align="left" width="200px" hspace="10" vspace="6"></a>
This repository is part of **[Phovea](http://phovea.caleydo.org/)**, a platform for developing web-based visualization applications. For tutorials, API docs, and more information about the build and deployment process, see the [documentation page](http://phovea.caleydo.org).


[phovea-image]: https://img.shields.io/badge/Phovea-Server%20Plugin-10ACDF.svg
[phovea-url]: https://phovea.caleydo.org
[circleci-image]: https://circleci.com/gh/phovea/phovea_server.svg?style=shield
[circleci-url]: https://circleci.com/gh/phovea/phovea_server
